#!/bin/bash

# Exit on any error
set -e

# Update system
apt update && apt upgrade -y

# Install dependencies
apt install build-essential libtool autotools-dev automake pkg-config bsdmainutils python3 libssl-dev libevent-dev libboost-system-dev libboost-filesystem-dev libboost-chrono-dev libboost-program-options-dev libboost-test-dev libboost-thread-dev libminiupnpc-dev libzmq3-dev libsqlite3-dev -y

# Download and install Bitcoin Core
cd /root
wget https://bitcoincore.org/bin/bitcoin-core-25.1/bitcoin-25.1-x86_64-linux-gnu.tar.gz
tar xzf bitcoin-25.1-x86_64-linux-gnu.tar.gz
install -m 0755 -o root -g root -t /usr/local/bin bitcoin-25.1/bin/*

# Configure Bitcoin
mkdir -p /root/.bitcoin
cat > /root/.bitcoin/bitcoin.conf << EOF
prune=550
maxconnections=40
maxuploadtarget=5000
daemon=1
server=1
txindex=0
EOF

# Start with PM2
pm2 start /usr/local/bin/bitcoind --name bitcoin-node

echo "
Setup complete! Monitor your node with:
bitcoin-cli getblockchaininfo
bitcoin-cli getnetworkinfo
tail -f /root/.bitcoin/debug.log

To stop: bitcoin-cli stop
PM2 commands:
pm2 status bitcoin-node
pm2 logs bitcoin-node
pm2 stop bitcoin-node
"